@@ -59,9 +59,9 @@ onewayid.data.frame <- function(x, attrib, id1 = names(x)[1], id2 = names(x)[2])
   x <- cbind(x, stplanr.ids)
 
   x_oneway <- dplyr::group_by_(x, quote(stplanr.key)) %>%
-    dplyr::mutate(is_two_way = ifelse(n() > 1, TRUE, FALSE)) %>%
-    dplyr::mutate_each("sum", attrib) %>%
-    dplyr::summarise_each_(dplyr::funs("first"), c(as.name(id1), as.name(id2), attrib, ~is_two_way))
+    dplyr::mutate_(is_two_way = "ifelse(n() > 1, TRUE, FALSE)") %>%
+    dplyr::mutate_at(.cols = attrib, .funs = sum) %>%
+    dplyr::summarise_at(as.character(c(as.name(id1), as.name(id2), attrib, 'is_two_way')),dplyr::funs("first"))
 
   x_oneway$stplanr.key <- NULL
 
